==> spacetime-7.4.4.tgz: package/zonefile/aliases.js <==
// tzs that dont exist in zoneinfo anymore
// cldraliases from timezonenames
// https://github.com/mj1856/timezonenames

// link-name : target
export default {
  'africa/asmera': 'africa/nairobi',
  'africa/timbuktu': 'africa/abidjan',
  'america/atka': 'america/adak',
  'america/coral_harbour': 'america/atikokan',

  'pacific/enderbury': 'pacific/kanton',
  'asia/volgograd': 'europe/volgograd',

  // argentina
  'america/argentina/comodrivadavia': 'america/catamarca',
  'america/argentina/buenos_aires': 'america/buenos_aires',
  'america/argentina/catamarca': 'america/catamarca',
  'america/argentina/cordoba': 'america/cordoba',
  'america/argentina/jujuy': 'america/jujuy',
  'america/argentina/mendoza': 'america/mendoza',
  'america/argentina/rosario': 'america/cordoba',

  'america/ensenada': 'america/tijuana',
  'america/fort_wayne': 'america/indianapolis',
  'america/godthab': 'america/nuuk',
  'america/indiana': 'america/indianapolis',
  'america/indiana/indianapolis': 'america/indianapolis',
  'america/kentucky': 'america/louisville',
  'america/kentucky/louisville': 'america/louisville',
  'america/north_dakota': 'america/boise',
  'america/knox_in': 'america/indiana/knox',
  'america/montreal': 'america/toronto',
  'america/porto_acre': 'america/rio_branco',
  'america/rosario': 'america/cordoba',
  'america/santa_isabel': 'america/tijuana',
  'america/shiprock': 'america/denver',
  'america/virgin': 'america/port_of_spain',
  'antarctica/south_pole': 'pacific/auckland',
  'asia/ashkhabad': 'asia/ashgabat',
  'asia/calcutta': 'asia/kolkata',
  'asia/chongqing': 'asia/shanghai',
  'asia/chungking': 'asia/shanghai',
  'asia/dacca': 'asia/dhaka',
  'asia/harbin': 'asia/shanghai',
  'asia/istanbul': 'europe/istanbul',
  'asia/kashgar': 'asia/urumqi',
  'asia/katmandu': 'asia/kathmandu',
  'asia/macao': 'asia/macau',
  'asia/rangoon': 'asia/yangon',
  'asia/saigon': 'asia/ho_chi_minh',
  'asia/tel_aviv': 'asia/jerusalem',
  'asia/thimbu': 'asia/thimphu',
  'asia/ujung_pandang': 'asia/makassar',
  'asia/ulan_bator': 'asia/ulaanbaatar',
  'atlantic/faeroe': 'atlantic/faroe',
  'atlantic/jan_mayen': 'europe/oslo',
  'australia/act': 'australia/sydney',
  'australia/canberra': 'australia/sydney',
  'australia/currie': 'australia/hobart',
  'australia/lhi': 'australia/lord_howe',
  'australia/north': 'australia/darwin',
  'australia/nsw': 'australia/sydney',
  'australia/queensland': 'australia/brisbane',
  'australia/south': 'australia/adelaide',
  'australia/tasmania': 'australia/hobart',
  'australia/victoria': 'australia/melbourne',
  'australia/west': 'australia/perth',
  'australia/yancowinna': 'australia/broken_hill',
  'brazil/acre': 'america/rio_branco',
  'brazil/denoronha': 'america/noronha',
  'brazil/east': 'america/sao_paulo',
  'brazil/west': 'america/manaus',
  'canada/atlantic': 'america/halifax',
  'canada/central': 'america/winnipeg',
  'canada/east-saskatchewan': 'america/regina',
  'canada/eastern': 'america/toronto',
  'canada/mountain': 'america/edmonton',
  'canada/newfoundland': 'america/st_johns',
  'canada/pacific': 'america/vancouver',
  'canada/saskatchewan': 'america/regina',
  'canada/yukon': 'america/whitehorse',
  'chile/continental': 'america/santiago',
  'chile/easterisland': 'pacific/easter',
  'cuba': 'america/havana',
  'egypt': 'africa/cairo',
  'eire': 'europe/dublin',
  'etc/greenwich': 'etc/gmt',
  'etc/uct': 'etc/utc',
  'etc/universal': 'etc/utc',
  'etc/zulu': 'etc/utc',
  'europe/belfast': 'europe/london',
  'europe/nicosia': 'asia/nicosia',
  'europe/tiraspol': 'europe/chisinau',
  'gb-eire': 'europe/london',
  'gb': 'europe/london',
  'gmt-0': 'etc/gmt',
  'gmt+0': 'etc/gmt',
  'gmt0': 'etc/gmt',
  'greenwich': 'etc/gmt',
  'hongkong': 'asia/hong_kong',
  'iceland': 'atlantic/reykjavik',
  'iran': 'asia/tehran',
  'israel': 'asia/jerusalem',
  'jamaica': 'america/jamaica',
  'japan': 'asia/tokyo',
  'kwajalein': 'pacific/kwajalein',
  'libya': 'africa/tripoli',
  'mexico/bajanorte': 'america/tijuana',
  'mexico/bajasur': 'america/mazatlan',
  'mexico/general': 'america/mexico_city',
  'navajo': 'america/denver',
  'nz-chat': 'pacific/chatham',
  'nz': 'pacific/auckland',
  'pacific/johnston': 'pacific/honolulu',
  'pacific/ponape': 'pacific/pohnpei',
  'pacific/samoa': 'pacific/pago_pago',
  'pacific/truk': 'pacific/chuuk',
  'pacific/yap': 'pacific/chuuk',
  'poland': 'europe/warsaw',
  'portugal': 'europe/lisbon',
  'prc': 'asia/shanghai',
  'roc': 'asia/taipei',
  'rok': 'asia/seoul',
  'singapore': 'asia/singapore',
  'turkey': 'europe/istanbul',
  'uct': 'etc/utc',
  'universal': 'etc/utc',
  'us/alaska': 'america/anchorage',
  'us/aleutian': 'america/adak',
  'us/arizona': 'america/phoenix',
  'us/central': 'america/chicago',
  'us/east-indiana': 'america/indianapolis',
  'us/eastern': 'america/new_york',
  'us/hawaii': 'pacific/honolulu',
  'us/indiana-starke': 'america/indiana/knox',
  'us/michigan': 'america/detroit',
  'us/mountain': 'america/denver',
  'us/pacific-new': 'america/los_angeles',
  'us/pacific': 'america/los_angeles',
  'us/samoa': 'pacific/pago_pago',
  'utc': 'etc/utc',
  'w-su': 'europe/moscow',
  'zulu': 'etc/utc',
  'etc/unknown': 'etc/utc',
  'europe/kiev': 'europe/kyiv',

}

==> spacetime-7.6.0.tgz: package/zonefile/aliases.js <==
// tzs that dont exist in zoneinfo anymore
// cldraliases from timezonenames
// https://github.com/mj1856/timezonenames

// link-name : target
export default {
  'africa/asmera': 'africa/nairobi',
  'africa/timbuktu': 'africa/abidjan',
  'america/atka': 'america/adak',
  'america/coral_harbour': 'america/atikokan',

  'pacific/enderbury': 'pacific/kanton',
  'asia/volgograd': 'europe/volgograd',

  // argentina
  'america/argentina/comodrivadavia': 'america/catamarca',
  'america/argentina/buenos_aires': 'america/buenos_aires',
  'america/argentina/catamarca': 'america/catamarca',
  'america/argentina/cordoba': 'america/cordoba',
  'america/argentina/jujuy': 'america/jujuy',
  'america/argentina/mendoza': 'america/mendoza',
  'america/argentina/rosario': 'america/cordoba',

  'america/ensenada': 'america/tijuana',
  'america/fort_wayne': 'america/indianapolis',
  'america/godthab': 'america/nuuk',
  'america/indiana': 'america/indianapolis',
  'america/indiana/indianapolis': 'america/indianapolis',
  'america/kentucky': 'america/louisville',
  'america/kentucky/louisville': 'america/louisville',
  'america/north_dakota': 'america/boise',
  'america/knox_in': 'america/indiana/knox',
  'america/montreal': 'america/toronto',
  'america/porto_acre': 'america/rio_branco',
  'america/rosario': 'america/cordoba',
  'america/santa_isabel': 'america/tijuana',
  'america/shiprock': 'america/denver',
  'america/virgin': 'america/port_of_spain',
  'antarctica/south_pole': 'pacific/auckland',
  'asia/ashkhabad': 'asia/ashgabat',
  'asia/calcutta': 'asia/kolkata',
  'asia/chongqing': 'asia/shanghai',
  'asia/chungking': 'asia/shanghai',
  'asia/dacca': 'asia/dhaka',
  'asia/harbin': 'asia/shanghai',
  'asia/istanbul': 'europe/istanbul',
  'asia/kashgar': 'asia/urumqi',
  'asia/katmandu': 'asia/kathmandu',
  'asia/macao': 'asia/macau',
  'asia/rangoon': 'asia/yangon',
  'asia/saigon': 'asia/ho_chi_minh',
  'asia/tel_aviv': 'asia/jerusalem',
  'asia/thimbu': 'asia/thimphu',
  'asia/ujung_pandang': 'asia/makassar',
  'asia/ulan_bator': 'asia/ulaanbaatar',
  'atlantic/faeroe': 'atlantic/faroe',
  'atlantic/jan_mayen': 'europe/oslo',
  'australia/act': 'australia/sydney',
  'australia/canberra': 'australia/sydney',
  'australia/currie': 'australia/hobart',
  'australia/lhi': 'australia/lord_howe',
  'australia/north': 'australia/darwin',
  'australia/nsw': 'australia/sydney',
  'australia/queensland': 'australia/brisbane',
  'australia/south': 'australia/adelaide',
  'australia/tasmania': 'australia/hobart',
  'australia/victoria': 'australia/melbourne',
  'australia/west': 'australia/perth',
  'australia/yancowinna': 'australia/broken_hill',
  'brazil/acre': 'america/rio_branco',
  'brazil/denoronha': 'america/noronha',
  'brazil/east': 'america/sao_paulo',
  'brazil/west': 'america/manaus',
  'canada/atlantic': 'america/halifax',
  'canada/central': 'america/winnipeg',
  'canada/east-saskatchewan': 'america/regina',
  'canada/eastern': 'america/toronto',
  'canada/mountain': 'america/edmonton',
  'canada/newfoundland': 'america/st_johns',
  'canada/pacific': 'america/vancouver',
  'canada/saskatchewan': 'america/regina',
  'canada/yukon': 'america/whitehorse',
  'chile/continental': 'america/santiago',
  'chile/easterisland': 'pacific/easter',
  cuba: 'america/havana',
  egypt: 'africa/cairo',
  eire: 'europe/dublin',
  'etc/greenwich': 'etc/gmt',
  'etc/uct': 'etc/utc',
  'etc/universal': 'etc/utc',
  'etc/zulu': 'etc/utc',
  'europe/belfast': 'europe/london',
  'europe/nicosia': 'asia/nicosia',
  'europe/tiraspol': 'europe/chisinau',
  'gb-eire': 'europe/london',
  gb: 'europe/london',
  'gmt-0': 'etc/gmt',
  'gmt+0': 'etc/gmt',
  gmt0: 'etc/gmt',
  greenwich: 'etc/gmt',
  hongkong: 'asia/hong_kong',
  iceland: 'atlantic/reykjavik',
  iran: 'asia/tehran',
  israel: 'asia/jerusalem',
  jamaica: 'america/jamaica',
  japan: 'asia/tokyo',
  kwajalein: 'pacific/kwajalein',
  libya: 'africa/tripoli',
  'mexico/bajanorte': 'america/tijuana',
  'mexico/bajasur': 'america/mazatlan',
  'mexico/general': 'america/mexico_city',
  navajo: 'america/denver',
  'nz-chat': 'pacific/chatham',
  nz: 'pacific/auckland',
  'pacific/johnston': 'pacific/honolulu',
  'pacific/ponape': 'pacific/pohnpei',
  'pacific/samoa': 'pacific/pago_pago',
  'pacific/truk': 'pacific/chuuk',
  'pacific/yap': 'pacific/chuuk',
  poland: 'europe/warsaw',
  portugal: 'europe/lisbon',
  prc: 'asia/shanghai',
  roc: 'asia/taipei',
  rok: 'asia/seoul',
  singapore: 'asia/singapore',
  turkey: 'europe/istanbul',
  uct: 'etc/utc',
  universal: 'etc/utc',
  'us/alaska': 'america/anchorage',
  'us/aleutian': 'america/adak',
  'us/arizona': 'america/phoenix',
  'us/central': 'america/chicago',
  'us/east-indiana': 'america/indianapolis',
  'us/eastern': 'america/new_york',
  'us/hawaii': 'pacific/honolulu',
  'us/indiana-starke': 'america/indiana/knox',
  'us/michigan': 'america/detroit',
  'us/mountain': 'america/denver',
  'us/pacific-new': 'america/los_angeles',
  'us/pacific': 'america/los_angeles',
  'us/samoa': 'pacific/pago_pago',
  utc: 'etc/utc',
  'w-su': 'europe/moscow',
  zulu: 'etc/utc',
  'etc/unknown': 'etc/utc',
  'europe/kiev': 'europe/kyiv',

  //rogue acronym results found in results of
  // Intl.supportedValuesOf('timeZone')
  cet: 'europe/paris',
  eet: 'europe/sofia',
  est: 'america/cancun',
  factory: 'etc/utc',
  hst: 'pacific/honolulu',
  met: 'europe/paris',
  mst: 'america/phoenix',
  wet: 'europe/lisbon'
}
